==> django-admin-material-dashboard-1.0.12.tar.gz: django-admin-material-dashboard-1.0.12/README.md <==
# [Django Material Dashboard](https://app-generator.dev/docs/products/django-libs/theme-material-dashboard.html)

Modern template for **[Django Admin](https://app-generator.dev/docs/products/django-libs/theme-material-dashboard.html)**, Auth Pages (registration included) crafted on top of **Material Dashboard**, an open-source **Bootstrap** design.

- [Django Admin Material](https://app-generator.dev/docs/products/django-libs/theme-material-dashboard.html) - **Documentation** & Support Links
- [Django Material Dashboard](https://app-generator.dev/product/material-dashboard/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- Design: **[Material Dashboard](https://app-generator.dev/docs/templates/bootstrap/material-dashboard.html)** (Bootstrap)
- **Sections Covered**: 
  - `Admin Section`, reserved for `superusers`
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

![Django Material Dashboard - Modern template for Django Admin Section crafted on top of a modern Bootstrap Design.](https://user-images.githubusercontent.com/51070104/169301658-6cf27993-c451-4cd4-9ffa-2968b8981167.png)

<br />

---
**[Django Material Dashboard](https://app-generator.dev/docs/products/django-libs/theme-material-dashboard.html)** - Modern Django Admin Interface provided by **[App-Generator](https://app-generator.dev)**

==> django-admin-material-dashboard-1.0.14.tar.gz: django-admin-material-dashboard-1.0.14/README.md <==
# [Django Material Dashboard](https://app-generator.dev/docs/products/django-libs/theme-material-dashboard.html)

Modern template for **[Django Admin](https://app-generator.dev/docs/products/django-libs/theme-material-dashboard.html)**, Auth Pages (registration included) crafted on top of **Material Dashboard**, an open-source **Bootstrap** design.

- [Django Admin Material](https://app-generator.dev/docs/products/django-libs/theme-material-dashboard.html) - **Documentation** & Support Links
- [Django Material Dashboard](https://app-generator.dev/product/material-dashboard/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- Design: **[Material Dashboard](https://app-generator.dev/docs/templates/bootstrap/material-dashboard.html)** (Bootstrap)
- **Sections Covered**: 
  - `Admin Section`, reserved for `superusers`
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

![Django Material Dashboard - Modern template for Django Admin Section crafted on top of a modern Bootstrap Design.](https://github.com/user-attachments/assets/532e06c1-1af3-4439-93fc-6de3a9d43c52)

<br />

---
**[Django Material Dashboard](https://app-generator.dev/docs/products/django-libs/theme-material-dashboard.html)** - Modern Django Admin Interface provided by **[App-Generator](https://app-generator.dev)**
